@@ -1,4 +1,4 @@
-# Copyright (c) 2006-2010 LOGILAB S.A. (Paris, FRANCE).
+# Copyright (c) 2006-2013 LOGILAB S.A. (Paris, FRANCE).
 # http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This program is free software; you can redistribute it and/or modify it under
@@ -13,16 +13,16 @@
 # You should have received a copy of the GNU General Public License along with
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-"""try to find more bugs in the code using astng inference capabilities
+"""try to find more bugs in the code using astroid inference capabilities
 """
 
 import re
 import shlex
 
-from logilab import astng
-from logilab.astng import InferenceError, NotFoundError, YES, Instance
+import astroid
+from astroid import InferenceError, NotFoundError, YES, Instance
 
-from pylint.interfaces import IASTNGChecker
+from pylint.interfaces import IAstroidChecker
 from pylint.checkers import BaseChecker
 from pylint.checkers.utils import safe_infer, is_super, check_messages
 
@@ -37,7 +37,7 @@ MSGS = {
     'E1103': ('%s %r has no %r member (but some types could not be inferred)',
               'maybe-no-member',
               'Used when a variable is accessed for an unexistent member, but \
-              astng was not able to interpret all possible types of this \
+              astroid was not able to interpret all possible types of this \
               variable.'),
     'E1111': ('Assigning to function call which doesn\'t return',
               'assignment-from-no-return',
@@ -58,7 +58,8 @@ MSGS = {
     'E1122': ('Duplicate keyword argument %r in function call',
               'duplicate-keyword-arg',
               'Used when a function call passes the same keyword argument \
-              multiple times.'),
+              multiple times.',
+              {'maxversion': (2, 6)}),
     'E1123': ('Passing unexpected keyword argument %r in function call',
               'unexpected-keyword-arg',
               'Used when a function call passes a keyword argument that \
@@ -68,13 +69,18 @@ MSGS = {
               'Used when a function call would result in assigning multiple \
               values to a function parameter, one value from a positional \
               argument and one from a keyword argument.'),
+    'E1125': ('Missing mandatory keyword argument %r',
+              'missing-kwoa',
+              'Used when a function call doesn\'t pass a mandatory \
+              keyword-only argument.',
+              {'minversion': (3, 0)}),
     }
 
 class TypeChecker(BaseChecker):
     """try to find bugs in the code using type inference
     """
 
-    __implements__ = (IASTNGChecker,)
+    __implements__ = (IAstroidChecker,)
 
     # configuration section name
     name = 'typecheck'
@@ -120,7 +126,7 @@ accessed. Python regular expressions are accepted.'}
             self.generated_members.extend(('REQUEST', 'acl_users', 'aq_parent'))
 
     def visit_assattr(self, node):
-        if isinstance(node.ass_type(), astng.AugAssign):
+        if isinstance(node.ass_type(), astroid.AugAssign):
             self.visit_getattr(node)
 
     def visit_delattr(self, node):
@@ -162,7 +168,7 @@ accessed. Python regular expressions are accepted.'}
                 inference_failure = True
                 continue
             # skip None anyway
-            if isinstance(owner, astng.Const) and owner.value is None:
+            if isinstance(owner, astroid.Const) and owner.value is None:
                 continue
             # XXX "super" / metaclass call
             if is_super(owner) or getattr(owner, 'type', None) == 'metaclass':
@@ -174,14 +180,14 @@ accessed. Python regular expressions are accepted.'}
                 continue
             try:
                 if not [n for n in owner.getattr(node.attrname)
-                        if not isinstance(n.statement(), astng.AugAssign)]:
+                        if not isinstance(n.statement(), astroid.AugAssign)]:
                     missingattr.add((owner, name))
                     continue
             except AttributeError:
                 # XXX method / function
                 continue
             except NotFoundError:
-                if isinstance(owner, astng.Function) and owner.decorators:
+                if isinstance(owner, astroid.Function) and owner.decorators:
                     continue
                 if isinstance(owner, Instance) and owner.has_dynamic_getattr():
                     continue
@@ -212,33 +218,34 @@ accessed. Python regular expressions are accepted.'}
                                  args=(owner.display_type(), name,
                                        node.attrname))
 
-
+    @check_messages('E1111', 'W1111')
     def visit_assign(self, node):
         """check that if assigning to a function call, the function is
         possibly returning something valuable
         """
-        if not isinstance(node.value, astng.CallFunc):
+        if not isinstance(node.value, astroid.CallFunc):
             return
         function_node = safe_infer(node.value.func)
         # skip class, generator and incomplete function definition
-        if not (isinstance(function_node, astng.Function) and
+        if not (isinstance(function_node, astroid.Function) and
                 function_node.root().fully_defined()):
             return
         if function_node.is_generator() \
                or function_node.is_abstract(pass_is_abstract=False):
             return
-        returns = list(function_node.nodes_of_class(astng.Return,
-                                                    skip_klass=astng.Function))
+        returns = list(function_node.nodes_of_class(astroid.Return,
+                                                    skip_klass=astroid.Function))
         if len(returns) == 0:
             self.add_message('E1111', node=node)
         else:
             for rnode in returns:
-                if not (isinstance(rnode.value, astng.Const)
+                if not (isinstance(rnode.value, astroid.Const)
                         and rnode.value.value is None):
                     break
             else:
                 self.add_message('W1111', node=node)
 
+    @check_messages(*(MSGS.keys()))
     def visit_callfunc(self, node):
         """check that called functions/methods are inferred to callable objects,
         and that the arguments passed to the function match the parameters in
@@ -250,7 +257,7 @@ accessed. Python regular expressions are accepted.'}
         keyword_args = set()
         num_positional_args = 0
         for arg in node.args:
-            if isinstance(arg, astng.Keyword):
+            if isinstance(arg, astroid.Keyword):
                 keyword = arg.arg
                 if keyword in keyword_args:
                     self.add_message('E1122', node=node, args=keyword)
@@ -265,18 +272,18 @@ accessed. Python regular expressions are accepted.'}
 
         # Note that BoundMethod is a subclass of UnboundMethod (huh?), so must
         # come first in this 'if..else'.
-        if isinstance(called, astng.BoundMethod):
+        if isinstance(called, astroid.BoundMethod):
             # Bound methods have an extra implicit 'self' argument.
             num_positional_args += 1
-        elif isinstance(called, astng.UnboundMethod):
+        elif isinstance(called, astroid.UnboundMethod):
             if called.decorators is not None:
                 for d in called.decorators.nodes:
-                    if isinstance(d, astng.Name) and (d.name == 'classmethod'):
+                    if isinstance(d, astroid.Name) and (d.name == 'classmethod'):
                         # Class methods have an extra implicit 'cls' argument.
                         num_positional_args += 1
                         break
-        elif (isinstance(called, astng.Function) or
-              isinstance(called, astng.Lambda)):
+        elif (isinstance(called, astroid.Function) or
+              isinstance(called, astroid.Lambda)):
             pass
         else:
             return
@@ -285,7 +292,7 @@ accessed. Python regular expressions are accepted.'}
             # Built-in functions have no argument information.
             return
 
-        if len( called.argnames() ) != len( set( called.argnames() ) ):
+        if len(called.argnames()) != len(set(called.argnames())):
             # Duplicate parameter name (see E9801).  We can't really make sense
             # of the function call in this case, so just return.
             return
@@ -295,15 +302,15 @@ accessed. Python regular expressions are accepted.'}
         parameters = []
         parameter_name_to_index = {}
         for i, arg in enumerate(called.args.args):
-            if isinstance(arg, astng.Tuple):
+            if isinstance(arg, astroid.Tuple):
                 name = None
                 # Don't store any parameter names within the tuple, since those
                 # are not assignable from keyword arguments.
             else:
-                if isinstance(arg, astng.Keyword):
+                if isinstance(arg, astroid.Keyword):
                     name = arg.arg
                 else:
-                    assert isinstance(arg, astng.AssName)
+                    assert isinstance(arg, astroid.AssName)
                     # This occurs with:
                     #    def f( (a), (b) ): pass
                     name = arg.name
@@ -314,6 +321,15 @@ accessed. Python regular expressions are accepted.'}
                 defval = None
             parameters.append([(name, defval), False])
 
+        kwparams = {}
+        for i, arg in enumerate(called.args.kwonlyargs):
+            if isinstance(arg, astroid.Keyword):
+                name = arg.arg
+            else:
+                assert isinstance(arg, astroid.AssName)
+                name = arg.name
+            kwparams[name] = [called.args.kw_defaults[i], False]
+
         # Match the supplied arguments against the function parameters.
 
         # 1. Match the positional arguments.
@@ -338,6 +354,12 @@ accessed. Python regular expressions are accepted.'}
                     self.add_message('E1124', node=node, args=keyword)
                 else:
                     parameters[i][1] = True
+            elif keyword in kwparams:
+                if kwparams[keyword][1]:  # XXX is that even possible?
+                    # Duplicate definition of function parameter.
+                    self.add_message('E1124', node=node, args=keyword)
+                else:
+                    kwparams[keyword][1] = True
             elif called.args.kwarg is not None:
                 # The keyword argument gets assigned to the **kwargs parameter.
                 pass
@@ -382,6 +404,12 @@ accessed. Python regular expressions are accepted.'}
                     display_name = repr(name)
                 self.add_message('E1120', node=node, args=display_name)
 
+        for name in kwparams:
+            defval, assigned = kwparams[name]
+            if defval is None and not assigned:
+                self.add_message('E1125', node=node, args=name)
+
+
 def register(linter):
     """required method to auto register this checker """
     linter.register_checker(TypeChecker(linter))
