@@ -51,6 +51,20 @@ def overridden_method(klass, name):
         return meth_node
     return None
 
+def _get_unpacking_extra_info(node, infered):
+    """return extra information to add to the message for unpacking-non-sequence
+    and unbalanced-tuple-unpacking errors
+    """
+    more = ''
+    infered_module = infered.root().name
+    if node.root().name == infered_module:
+        if node.lineno == infered.lineno:
+            more = ' %s' % infered.as_string()
+        elif infered.lineno:
+            more = ' defined at line %s' % infered.lineno
+    elif infered.lineno:
+        more = ' defined at line %s of %s' % (infered.lineno, infered_module)
+    return more
 
 MSGS = {
     'E0601': ('Using variable %r before assignment',
@@ -119,11 +133,17 @@ MSGS = {
               a list comprehension or a generator expression) is used outside \
               the loop.'),
 
-    'W0632': ('Possible unbalanced tuple unpacking: '
+    'W0632': ('Possible unbalanced tuple unpacking with '
+              'sequence%s: '
               'left side has %d label(s), right side has %d value(s)',
               'unbalanced-tuple-unpacking',
               'Used when there is an unbalanced tuple unpacking in assignment'),
 
+    'W0633': ('Attempting to unpack a non-sequence%s',
+              'unpacking-non-sequence',
+              'Used when something which is not '
+              'a sequence is used in an unpack assignment'),
+
     }
 
 class VariablesChecker(BaseChecker):
@@ -542,26 +562,54 @@ builtins. Remember that you should avoid to define new builtins when possible.'
                 continue
             self._check_module_attrs(node, module, name.split('.'))
 
-    @check_messages('unbalanced-tuple-unpacking')
+    @check_messages('unbalanced-tuple-unpacking', 'unpacking-non-sequence')
     def visit_assign(self, node):
-        """Check unbalanced tuple unpacking for assignments"""
+        """Check unbalanced tuple unpacking for assignments
+        and unpacking non-sequences.
+        """
         if not isinstance(node.targets[0], (astroid.Tuple, astroid.List)):
             return
-        try:
-            infered = node.value.infer().next()
-        except astroid.InferenceError:
-            return
-        if not isinstance(infered, (astroid.Tuple, astroid.List)):
-            return
+
         targets = node.targets[0].itered()
-        values = infered.itered()
         if any(not isinstance(target_node, astroid.AssName)
                for target_node in targets):
             return
-        if len(targets) != len(values):
-            self.add_message('unbalanced-tuple-unpacking',
-                             node=node,
-                             args=(len(targets), len(values)))
+
+        try:
+            for infered in node.value.infer():
+                self._check_unpacking(infered, node, targets)
+        except astroid.InferenceError:
+            return
+
+    def _check_unpacking(self, infered, node, targets):
+        """ Check for unbalanced tuple unpacking
+        and unpacking non sequences.
+        """
+        if infered is astroid.YES:
+            return
+        if isinstance(infered, (astroid.Tuple, astroid.List)):
+            # attempt to check unpacking is properly balanced
+            values = infered.itered()
+            if len(targets) != len(values):
+                self.add_message('unbalanced-tuple-unpacking', node=node,
+                                 args=(_get_unpacking_extra_info(node, infered),
+                                       len(targets),
+                                       len(values)))
+        # attempt to check unpacking may be possible (ie RHS is iterable)
+        elif isinstance(infered, astroid.Instance):
+            for meth in ('__iter__', '__getitem__'):
+                try:
+                    infered.getattr(meth)
+                    break
+                except astroid.NotFoundError:
+                    continue
+            else:
+                self.add_message('unpacking-non-sequence', node=node,
+                                 args=(_get_unpacking_extra_info(node, infered),))
+        else:
+            self.add_message('unpacking-non-sequence', node=node,
+                             args=(_get_unpacking_extra_info(node, infered),))
+
 
     def _check_module_attrs(self, node, module, module_names):
         """check that module_names (list of string) are accessible through the
