@@ -6,12 +6,14 @@ else
     PYVERSIONS=`pyversions -iv`
 fi
 
+cd `dirname $0`
+
 for ver in $PYVERSIONS; do  
     echo "@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@"
     echo `python$ver -V`
     echo "^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^"
-    python$ver runtests.py
+    python$ver `which pytest`
     echo "^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^"
     echo `python$ver -V` -OO
-    python$ver -OO runtests.py
+    python$ver -OO `which pytest`
 done
