@@ -1,13 +1,13 @@
 # pylint: disable=C0103
 
 ''' Test that y is defined properly, z is not.
-    Default defining methods are __init__, 
+    Default defining methods are __init__,
     __new__, and setUp.
     Order of methods should not matter. '''
 
 __revision__ = ''
 
-class A:
+class A(object):
     ''' class A '''
 
     def __init__(self):
