@@ -4,7 +4,7 @@
 __revision__ = 0
 
 
-class Abcd:
+class Abcd(object):
     """dummy class"""
 
     def __init__(truc):
@@ -13,6 +13,7 @@ class Abcd:
 
     def abdc(yoo):
         """another test"""
-
+        print yoo
     def edf(self):
         """just another method"""
+        print 'yapudju in', self
