@@ -1,4 +1,4 @@
-# pylint: disable-msg=R0903
+# pylint: disable=R0903
 """check use of super"""
 __revision__ = None
 
@@ -19,4 +19,13 @@ class NewAaaa(object):
 
     def __init__(self):
         super(object, self).__init__()
-        
+
+class Py3kAaaa(NewAaaa):
+    """new style"""
+    def __init__(self):
+        super().__init__()
+
+class Py3kWrongSuper(Py3kAaaa):
+    """new style"""
+    def __init__(self):
+        super(NewAaaa, self).__init__()
