@@ -1,12 +1,12 @@
-# pylint:disable-msg=R0201
+# pylint:disable=R0201
 """Checks that class variables are seen as inherited !
 """
 __revision__ = ''
 
-class BaseClass:
+class BaseClass(object):
     """A simple base class
     """
-    
+
     def __init__(self):
         self.base_var = {}
 
