@@ -1,7 +1,7 @@
 """test min methods"""
 __revision__ = None
 
-class Aaaa:
+class Aaaa(object):
     """yo"""
     def __init__(self):
         pass
