@@ -1,15 +1,15 @@
 """test max methods"""
 __revision__ = None
 
-class Aaaa:
+class Aaaa(object):
     """yo"""
     def __init__(self):
         pass
-    
+
     def meth1(self):
         """hehehe"""
         raise NotImplementedError
-    
+
     def meth2(self):
         """hehehe"""
         return 'Yo', self
