@@ -10,5 +10,9 @@ def func(arg1, arg2):
     """
     return arg2, arg1
 
-mydict = {'arg1':2, 'arg2': 4}
-func(**mydict)
+MYDICT = {'arg1':2, 'arg2': 4}
+func(**MYDICT)
+
+def coolfunc(*args, **kwargs):
+    """magic function"""
+    return func(*args, **kwargs)
