@@ -2,9 +2,9 @@
 
 __revision__ = None
 
-class Abcd:
+class Abcd(object):
     """dummy"""
-    
+
     def method1(self):
         """hehe"""
     method1 = staticmethod(method1)
