@@ -2,10 +2,10 @@
 
 __revision__ = 0
 
-class Abcd:
+class Abcd(object):
     '''dummy'''
     def __init__(self):
-        self.aarg = False 
+        self.aarg = False
     def abcd(self, aaa=1, bbbb=None):
         """hehehe"""
         print self, aaa, bbbb
