@@ -42,19 +42,12 @@ class LintTestNonExistentModuleTC(LintTestUsingModule):
     _get_expected = lambda self: 'F:  1: No module named %snonexistent%s\n' % (quote, quote)
     tags = testlib.Tags(('generated','pylint_input_%s' % module))
 
-class LintTestNonExistentFileTC(LintTestUsingFile):
-    module = join(INPUT_DIR, 'nonexistent.py')
-    _get_expected = lambda self: 'F:  1: No module named %s\n' % self.module[len(getcwd())+1 :]
-    tags = testlib.Tags(('generated', 'pylint_input_%s' % module))
-    def test_functionality(self):
-        self._test([self.module])
-
 class TestTests(testlib.TestCase):
     """check that all testable messages have been checked"""
     @testlib.tag('coverage')
     def test_exhaustivity(self):
         # skip fatal messages
-        todo = [msgid for msgid in linter._messages if msgid[0] != 'F']
+        todo = [msg.msgid for msg in linter.messages if msg.msgid[0] != 'F']
         for msgid in test_reporter.message_ids:
             try:
                 todo.remove(msgid)
@@ -89,7 +82,7 @@ def cb_file(*args):
         return base_cb_file(*args)
 
 callbacks = [cb_test_gen(LintTestUsingModule),
-    cb_file]
+             cb_file]
 
 # Gen tests
 
@@ -103,8 +96,6 @@ def gen_tests(filter_rgx):
 
     if is_to_run('nonexistent'):
         tests.append(LintTestNonExistentModuleTC)
-        if not MODULES_ONLY:
-            tests.append(LintTestNonExistentFileTC)
 
     tests.append(LintBuiltinModuleTest)
 
