@@ -26,22 +26,16 @@ from logilab.common.compat import reload
 from pylint import config
 from pylint.lint import PyLinter, Run, UnknownMessage, preprocess_options, \
      ArgumentPreprocessingError
-from pylint.utils import sort_msgs, PyLintASTWalker, MSG_STATE_SCOPE_CONFIG, \
-     MSG_STATE_SCOPE_MODULE, tokenize_module
+from pylint.utils import MSG_STATE_SCOPE_CONFIG, MSG_STATE_SCOPE_MODULE, \
+    PyLintASTWalker, MessageDefinition, build_message_def, tokenize_module
 from pylint.testutils import TestReporter
 from pylint.reporters import text
 from pylint import checkers
 
-class SortMessagesTC(TestCase):
-
-    def test(self):
-        l = ['E0501', 'E0503', 'F0002', 'I0201', 'W0540',
-             'R0202', 'F0203', 'R0220', 'W0321', 'I0001']
-        self.assertEqual(sort_msgs(l), ['E0501', 'E0503',
-                                         'W0321', 'W0540',
-                                         'R0202', 'R0220',
-                                         'I0001', 'I0201',
-                                         'F0002', 'F0203',])
+if sys.platform == 'win32':
+     HOME = 'USERPROFILE'
+else:
+     HOME = 'HOME'
 
 class GetNoteMessageTC(TestCase):
     def test(self):
@@ -83,11 +77,50 @@ class PyLinterTC(TestCase):
         checkers.initialize(self.linter)
         self.linter.set_reporter(TestReporter())
 
+    def _compare_messages(self, desc, msg, checkerref=False):
+        # replace \r\n with \n, because
+        # logilab.common.textutils.normalize_text
+        # uses os.linesep, which will
+        # not properly compare with triple
+        # quoted multilines used in these tests 
+        self.assertMultiLineEqual(desc,
+             msg.format_help(checkerref=checkerref)
+                .replace('\r\n', '\n'))
+
+    def test_check_message_id(self):
+        self.assertIsInstance(self.linter.check_message_id('F0001'),
+                              MessageDefinition)
+        self.assertRaises(UnknownMessage,
+                          self.linter.check_message_id, 'YB12')
+
     def test_message_help(self):
-        msg = self.linter.get_message_help('F0001', checkerref=True)
-        expected = ':F0001 (fatal):\n  Used when an error occurred preventing the analysis of a module (unable to\n  find it for instance). This message belongs to the master checker.'
-        self.assertMultiLineEqual(msg, expected)
-        self.assertRaises(UnknownMessage, self.linter.get_message_help, 'YB12')
+        msg = self.linter.check_message_id('F0001')
+        self._compare_messages(
+            ''':fatal (F0001):
+  Used when an error occurred preventing the analysis of a module (unable to
+  find it for instance). This message belongs to the master checker.''',
+            msg, checkerref=True)
+        self._compare_messages(
+            ''':fatal (F0001):
+  Used when an error occurred preventing the analysis of a module (unable to
+  find it for instance).''',
+            msg, checkerref=False)
+
+    def test_message_help_minmax(self):
+        # build the message manually to be python version independant
+        msg = build_message_def(self.linter._checkers['typecheck'][0],
+                                'E1122', checkers.typecheck.MSGS['E1122'])
+        self._compare_messages(
+            ''':duplicate-keyword-arg (E1122): *Duplicate keyword argument %r in function call*
+  Used when a function call passes the same keyword argument multiple times.
+  This message belongs to the typecheck checker. It can't be emitted when using
+  Python >= 2.6.''',
+            msg, checkerref=True)
+        self._compare_messages(
+            ''':duplicate-keyword-arg (E1122): *Duplicate keyword argument %r in function call*
+  Used when a function call passes the same keyword argument multiple times.
+  This message can't be emitted when using Python >= 2.6.''',
+            msg, checkerref=False)
 
     def test_enable_message(self):
         linter = self.linter
@@ -147,7 +180,7 @@ class PyLinterTC(TestCase):
         linter.open()
         filepath = join(INPUTDIR, 'func_block_disable_msg.py')
         linter.set_current_module('func_block_disable_msg')
-        astroid = linter.get_astroid(filepath, 'func_block_disable_msg')
+        astroid = linter.get_ast(filepath, 'func_block_disable_msg')
         linter.process_tokens(tokenize_module(astroid))
         orig_state = linter._module_msgs_state.copy()
         linter._module_msgs_state = {}
@@ -191,7 +224,7 @@ class PyLinterTC(TestCase):
 
         self.assertEqual(17, linter._suppression_mapping['W0613', 18])
         self.assertEqual(30, linter._suppression_mapping['E1101', 33])
-        self.assert_(('E1101', 46) not in linter._suppression_mapping)
+        self.assertTrue(('E1101', 46) not in linter._suppression_mapping)
         self.assertEqual(1, linter._suppression_mapping['C0302', 18])
         self.assertEqual(1, linter._suppression_mapping['C0302', 50])
         # This is tricky. While the disable in line 106 is disabling
@@ -238,7 +271,7 @@ class PyLinterTC(TestCase):
         finally:
             sys.stdout = sys.__stdout__
         # cursory examination of the output: we're mostly testing it completes
-        self.assertTrue(':C0112 (empty-docstring): *Empty %s docstring*' in output)
+        self.assertIn(':empty-docstring (C0112): *Empty %s docstring*', output)
 
     def test_lint_ext_module_with_file_output(self):
         self.linter.set_reporter(text.TextReporter())
@@ -259,6 +292,13 @@ class PyLinterTC(TestCase):
             except:
                 pass
 
+    def test_lint_should_analyze_file(self):
+        self.linter.set_reporter(text.TextReporter())
+        self.linter.config.files_output = True
+        self.linter.should_analyze_file = lambda *args: False
+        self.linter.check('os')
+        self.assertFalse(os.path.exists('pylint_os.txt'))
+
     def test_enable_report(self):
         self.assertEqual(self.linter.report_is_enabled('RP0001'), True)
         self.linter.disable('RP0001')
@@ -339,6 +379,23 @@ class PyLinterTC(TestCase):
             ['C:  1: Line too long (1/2)', 'C:  2: Line too long (3/4)'],
             self.linter.reporter.messages)
 
+    def test_add_renamed_message(self):
+        self.linter.add_renamed_message('C9999', 'old-bad-name', 'invalid-name')
+        self.assertEqual('invalid-name', 
+                         self.linter.check_message_id('C9999').symbol)
+        self.assertEqual('invalid-name', 
+                         self.linter.check_message_id('old-bad-name').symbol)
+
+    def test_renamed_message_register(self):
+         class Checker(object):
+              msgs = {'W1234': ('message', 'msg-symbol', 'msg-description',
+                                {'old_names': [('W0001', 'old-symbol')]})}
+         self.linter.register_messages(Checker())
+         self.assertEqual('msg-symbol', 
+                          self.linter.check_message_id('W0001').symbol)
+         self.assertEqual('msg-symbol', 
+                          self.linter.check_message_id('old-symbol').symbol)
+         
 
 class ConfigTC(TestCase):
 
@@ -369,9 +426,9 @@ class ConfigTC(TestCase):
 
     def test_pylintrc(self):
         fake_home = tempfile.mkdtemp('fake-home')
-        home = os.environ['HOME']
+        home = os.environ[HOME]
         try:
-            os.environ['HOME'] = fake_home
+            os.environ[HOME] = fake_home
             self.assertEqual(config.find_pylintrc(), None)
             os.environ['PYLINTRC'] = join(tempfile.gettempdir(), '.pylintrc')
             self.assertEqual(config.find_pylintrc(), None)
@@ -379,7 +436,7 @@ class ConfigTC(TestCase):
             self.assertEqual(config.find_pylintrc(), None)
         finally:
             os.environ.pop('PYLINTRC', '')
-            os.environ['HOME'] = home
+            os.environ[HOME] = home
             rmtree(fake_home, ignore_errors=True)
             reload(config)
 
@@ -397,12 +454,12 @@ class ConfigTC(TestCase):
                           'a/b/c/__init__.py', 'a/b/c/d/__init__.py'], chroot)
             os.chdir(chroot)
             fake_home = tempfile.mkdtemp('fake-home')
-            home = os.environ['HOME']
+            home = os.environ[HOME]
             try:
-                os.environ['HOME'] = fake_home
+                os.environ[HOME] = fake_home
                 self.assertEqual(config.find_pylintrc(), None)
             finally:
-                os.environ['HOME'] = home
+                os.environ[HOME] = home
                 os.rmdir(fake_home)
             results = {'a'       : join(chroot, 'a', 'pylintrc'),
                        'a/b'     : join(chroot, 'a', 'b', 'pylintrc'),
@@ -427,8 +484,8 @@ class ConfigTC(TestCase):
         chdir(cdir)
 
         fake_home = tempfile.mkdtemp('fake-home')
-        home = os.environ['HOME']
-        os.environ['HOME'] = fake_home
+        home = os.environ[HOME]
+        os.environ[HOME] = fake_home
         try:
             create_files(['a/pylintrc', 'a/b/pylintrc', 'a/b/c/d/__init__.py'], chroot)
             os.chdir(chroot)
@@ -442,7 +499,7 @@ class ConfigTC(TestCase):
                 os.chdir(join(chroot, basedir))
                 self.assertEqual(config.find_pylintrc(), expected)
         finally:
-            os.environ['HOME'] = home
+            os.environ[HOME] = home
             rmtree(fake_home, ignore_errors=True)
             os.chdir(HERE)
             rmtree(chroot)
