@@ -15,6 +15,8 @@
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 """functional/non regression tests for pylint"""
 
+import collections
+import contextlib
 import sys
 import re
 
@@ -36,6 +38,7 @@ from pylint.lint import PyLinter
 SYS_VERS_STR = '%d%d' % sys.version_info[:2]
 TITLE_UNDERLINES = ['', '=', '-', '.']
 PREFIX = abspath(dirname(__file__))
+PY3K = sys.version_info[0] == 3
 
 def fix_path():
     sys.path.insert(0, PREFIX)
@@ -45,11 +48,11 @@ def get_tests_info(input_dir, msg_dir, prefix, suffix):
 
     We use following conventions for input files and messages:
     for different inputs:
-        don't test for python  <   x.y    ->  input   =  <name>_pyxy.py
-        don't test for python  >=  x.y    ->  input   =  <name>_py_xy.py
+        test for python  >= x.y    ->  input   =  <name>_pyxy.py
+        test for python  <  x.y    ->  input   =  <name>_py_xy.py
     for one input and different messages:
-        message for python     <=  x.y    ->  message =  <name>_pyxy.txt
-        higher versions                   ->  message with highest num
+        message for python >=  x.y ->  message =  <name>_pyxy.txt
+        lower versions             ->  message with highest num
     """
     result = []
     for fname in glob(join(input_dir, prefix + '*' + suffix)):
@@ -97,6 +100,10 @@ class TestReporter(BaseReporter):
         if obj:
             obj = ':%s' % obj
         sigle = msg_id[0]
+        if PY3K and linesep != '\n':
+            # 2to3 writes os.linesep instead of using
+            # the previosly used line separators
+            msg = msg.replace('\r\n', '\n')
         self.messages.append('%s:%3s%s: %s' % (sigle, line, obj, msg))
 
     def finalize(self):
@@ -110,8 +117,73 @@ class TestReporter(BaseReporter):
     def display_results(self, layout):
         """ignore layouts"""
 
-# Init
 
+class Message(collections.namedtuple('Message',
+                                     ['msg_id', 'line', 'node', 'args'])):
+    def __new__(cls, msg_id, line=None, node=None, args=None):
+        return tuple.__new__(cls, (msg_id, line, node, args))
+
+
+class UnittestLinter(object):
+    """A fake linter class to capture checker messages."""
+
+    def __init__(self):
+        self._messages = []
+        self.stats = {}
+
+    def release_messages(self):
+        try:
+            return self._messages
+        finally:
+            self._messages = []
+
+    def add_message(self, msg_id, line=None, node=None, args=None):
+        self._messages.append(Message(msg_id, line, node, args))
+
+    def is_message_enabled(self, *unused_args):
+        return True
+
+    def add_stats(self, **kwargs):
+        for name, value in kwargs.iteritems():
+            self.stats[name] = value
+
+
+class CheckerTestCase(testlib.TestCase):
+    """A base testcase class for unittesting individual checker classes."""
+    CHECKER_CLASS = None
+    CONFIG = {}
+
+    def setUp(self):
+        self.linter = UnittestLinter()
+        self.checker = self.CHECKER_CLASS(self.linter) # pylint: disable=not-callable
+        for key, value in self.CONFIG.iteritems():
+            setattr(self.checker.config, key, value)
+        self.checker.open()
+        self.checker.stats = self.linter.stats
+
+    @contextlib.contextmanager
+    def assertNoMessages(self):
+        """Assert that no messages are added by the given method."""
+        with self.assertAddsMessages():
+            yield
+
+    @contextlib.contextmanager
+    def assertAddsMessages(self, *messages):
+        """Assert that exactly the given method adds the given messages.
+
+        The list of messages must exactly match *all* the messages added by the
+        method. Additionally, we check to see whether the args in each message can
+        actually be substituted into the message string.
+        """
+        yield
+        got = self.linter.release_messages()
+        msg = ('Expected messages did not match actual.\n'
+               'Expected:\n%s\nGot:\n%s' % ('\n'.join(repr(m) for m in messages),
+                                            '\n'.join(repr(m) for m in got)))
+        self.assertEqual(list(messages), got, msg)
+
+
+# Init
 test_reporter = TestReporter()
 linter = PyLinter()
 linter.set_reporter(test_reporter)
@@ -146,10 +218,10 @@ class LintTestUsingModule(testlib.TestCase):
     _TEST_TYPE = 'module'
 
     def shortDescription(self):
-        values = { 'mode' : self._TEST_TYPE,
-                   'input': self.module,
-                   'pkg':   self.package,
-                   'cls':   self.__class__.__name__}
+        values = {'mode' : self._TEST_TYPE,
+                  'input': self.module,
+                  'pkg':   self.package,
+                  'cls':   self.__class__.__name__}
 
         if self.package == self.DEFAULT_PACKAGE:
             msg = '%(mode)s test of input file "%(input)s" (%(cls)s)'
@@ -179,14 +251,14 @@ class LintTestUsingModule(testlib.TestCase):
             ex.__str__ = exception_str
             raise
         got = self.linter.reporter.finalize()
-        self.assertMultiLineEqual(got, self._get_expected())
+        self.assertMultiLineEqual(self._get_expected(), got)
 
 
     def _get_expected(self):
         if self.module.startswith('func_noerror_'):
             expected = ''
         else:
-            output = open(self.output)
+            output = open(self.output, 'U')
             expected = output.read().strip() + '\n'
             output.close()
         return expected
