@@ -20,8 +20,8 @@ main pylint class
 import re
 import sys
 import tokenize
-from warnings import warn
 import os
+from warnings import warn
 from os.path import dirname, basename, splitext, exists, isdir, join, normpath
 
 from logilab.common.interface import implements
@@ -43,7 +43,6 @@ class EmptyReport(Exception):
     """raised when a report is empty and so should not be displayed"""
 
 
-
 MSG_TYPES = {
     'I' : 'info',
     'C' : 'convention',
@@ -77,17 +76,6 @@ class WarningScope(object):
     NODE = 'node-based-msg'
 
 
-def sort_msgs(msgids):
-    """sort message identifiers according to their category first"""
-    msgs = {}
-    for msg in msgids:
-        msgs.setdefault(msg[0], []).append(msg)
-    result = []
-    for m_id in _MSG_ORDER:
-        if m_id in msgs:
-            result.extend( sorted(msgs[m_id]) )
-    return result
-
 def get_module_and_frameid(node):
     """return the module name and the frame id in the module"""
     frame = node.frame()
@@ -122,18 +110,79 @@ def tokenize_module(module):
         return list(tokenize.generate_tokens(readline))
     return list(tokenize.tokenize(readline))
 
+def build_message_def(checker, msgid, msg_tuple):
+    if implements(checker, (IRawChecker, ITokenChecker)):
+        default_scope = WarningScope.LINE
+    else:
+        default_scope = WarningScope.NODE
+    options = {}
+    if len(msg_tuple) > 3:
+        (msg, symbol, descr, options) = msg_tuple
+    elif len(msg_tuple) > 2:
+        (msg, symbol, descr) = msg_tuple[:3]
+    else:
+        # messages should have a symbol, but for backward compatibility
+        # they may not.
+        (msg, descr) = msg_tuple
+        warn("[pylint 0.26] description of message %s doesn't include "
+             "a symbolic name" % msgid, DeprecationWarning)
+        symbol = None
+    options.setdefault('scope', default_scope)
+    return MessageDefinition(checker, msgid, msg, descr, symbol, **options)
+
 
 class MessageDefinition(object):
-    def __init__(self, checker, msgid, msg, descr, symbol, scope):
+    def __init__(self, checker, msgid, msg, descr, symbol, scope,
+                 minversion=None, maxversion=None, old_names=None):
+        self.checker = checker
         assert len(msgid) == 5, 'Invalid message id %s' % msgid
         assert msgid[0] in MSG_TYPES, \
                'Bad message type %s in %r' % (msgid[0], msgid)
         self.msgid = msgid
         self.msg = msg
         self.descr = descr
-        self.checker = checker
         self.symbol = symbol
         self.scope = scope
+        self.minversion = minversion
+        self.maxversion = maxversion
+        self.old_names = old_names or []
+
+    def may_be_emitted(self):
+        """return True if message may be emitted using the current interpreter"""
+        if self.minversion is not None and self.minversion > sys.version_info:
+            return False
+        if self.maxversion is not None and self.maxversion <= sys.version_info:
+            return False
+        return True
+
+    def format_help(self, checkerref=False):
+        """return the help string for the given message id"""
+        desc = self.descr
+        if checkerref:
+            desc += ' This message belongs to the %s checker.' % \
+                   self.checker.name
+        title = self.msg
+        if self.symbol:
+            msgid = '%s (%s)' % (self.symbol, self.msgid)
+        else:
+            msgid = self.msgid
+        if self.minversion or self.maxversion:
+            restr = []
+            if self.minversion:
+                restr.append('< %s' % '.'.join([str(n) for n in self.minversion]))
+            if self.maxversion:
+                restr.append('>= %s' % '.'.join([str(n) for n in self.maxversion]))
+            restr = ' or '.join(restr)
+            if checkerref:
+                desc += " It can't be emitted when using Python %s." % restr
+            else:
+                desc += " This message can't be emitted when using Python %s." % restr
+        desc = normalize_text(' '.join(desc.split()), indent='  ')
+        if title != '%s':
+            title = title.splitlines()[0]
+            return ':%s: *%s*\n%s' % (msgid, title, desc)
+        return ':%s:\n%s' % (msgid, desc)
+
 
 class MessagesHandlerMixIn(object):
     """a mix-in class containing all the messages related methods for the main
@@ -141,10 +190,15 @@ class MessagesHandlerMixIn(object):
     """
 
     def __init__(self):
-        # dictionary of registered messages
+        # Primary registry for all active messages (i.e. all messages
+        # that can be emitted by pylint for the underlying Python
+        # version). It contains the 1:1 mapping from symbolic names
+        # to message definition objects.
         self._messages = {}
-        # dictionary from string symbolic id to Message object.
-        self._messages_by_symbol = {}
+        # Maps alternative names (numeric IDs, deprecated names) to
+        # message definitions. May contain several names for each definition
+        # object.
+        self._alternative_names = {}
         self._msgs_state = {}
         self._module_msgs_state = {} # None
         self._raw_module_msgs_state = {}
@@ -153,6 +207,16 @@ class MessagesHandlerMixIn(object):
         self._ignored_msgs = {}
         self._suppression_mapping = {}
 
+    def add_renamed_message(self, old_id, old_symbol, new_symbol):
+        """Register the old ID and symbol for a warning that was renamed.
+
+        This allows users to keep using the old ID/symbol in suppressions.
+        """
+        msg = self.check_message_id(new_symbol)
+        msg.old_names.append((old_id, old_symbol))
+        self._alternative_names[old_id] = msg
+        self._alternative_names[old_symbol] = msg
+
     def register_messages(self, checker):
         """register a dictionary of messages
 
@@ -162,65 +226,26 @@ class MessagesHandlerMixIn(object):
         message ids should be a string of len 4, where the two first characters
         are the checker id and the two last the message id in this checker
         """
-        msgs_dict = checker.msgs
         chkid = None
-
-        for msgid, msg_tuple in msgs_dict.iteritems():
-            if implements(checker, (IRawChecker, ITokenChecker)):
-                scope = WarningScope.LINE
-            else:
-                scope = WarningScope.NODE
-            if len(msg_tuple) > 2:
-                (msg, msgsymbol, msgdescr) = msg_tuple[:3]
-                assert msgsymbol not in self._messages_by_symbol, \
-                    'Message symbol %r is already defined' % msgsymbol
-                if len(msg_tuple) > 3:
-                    if 'scope' in msg_tuple[3]:
-                        scope = msg_tuple[3]['scope']
-                    if 'minversion' in msg_tuple[3]:
-                        minversion = msg_tuple[3]['minversion']
-                        if minversion > sys.version_info:
-                            self._msgs_state[msgid] = False
-                            continue
-                    if 'maxversion' in msg_tuple[3]:
-                        maxversion = msg_tuple[3]['maxversion']
-                        if maxversion <= sys.version_info:
-                            self._msgs_state[msgid] = False
-                            continue
-            else:
-                # messages should have a symbol, but for backward compatibility
-                # they may not.
-                (msg, msgdescr) = msg_tuple
-                warn("[pylint 0.26] description of message %s doesn't include "
-                     "a symbolic name" % msgid, DeprecationWarning)
-                msgsymbol = None
+        for msgid, msg_tuple in checker.msgs.iteritems():
+            msg = build_message_def(checker, msgid, msg_tuple)
+            assert msg.symbol not in self._messages, \
+                    'Message symbol %r is already defined' % msg.symbol
             # avoid duplicate / malformed ids
-            assert msgid not in self._messages, \
+            assert msg.msgid not in self._alternative_names, \
                    'Message id %r is already defined' % msgid
-            assert chkid is None or chkid == msgid[1:3], \
+            assert chkid is None or chkid == msg.msgid[1:3], \
                    'Inconsistent checker part in message id %r' % msgid
-            chkid = msgid[1:3]
-            msg = MessageDefinition(checker, msgid, msg, msgdescr, msgsymbol, scope)
-            self._messages[msgid] = msg
-            self._messages_by_symbol[msgsymbol] = msg
-            self._msgs_by_category.setdefault(msgid[0], []).append(msgid)
-
-    def get_message_help(self, msgid, checkerref=False):
-        """return the help string for the given message id"""
-        msg = self.check_message_id(msgid)
-        desc = normalize_text(' '.join(msg.descr.split()), indent='  ')
-        if checkerref:
-            desc += ' This message belongs to the %s checker.' % \
-                   msg.checker.name
-        title = msg.msg
-        if msg.symbol:
-            symbol_part = ' (%s)' % msg.symbol
-        else:
-            symbol_part = ''
-        if title != '%s':
-            title = title.splitlines()[0]
-            return ':%s%s: *%s*\n%s' % (msg.msgid, symbol_part, title, desc)
-        return ':%s%s:\n%s' % (msg.msgid, symbol_part, desc)
+            chkid = msg.msgid[1:3]
+            if not msg.may_be_emitted():
+                self._msgs_state[msg.msgid] = False
+                continue
+            self._messages[msg.symbol] = msg
+            self._alternative_names[msg.msgid] = msg
+            for old_id, old_symbol in msg.old_names:
+                self._alternative_names[old_id] = msg
+                self._alternative_names[old_symbol] = msg
+            self._msgs_by_category.setdefault(msg.msgid[0], []).append(msg.msgid)
 
     def disable(self, msgid, scope='package', line=None):
         """don't output message of the given id"""
@@ -240,7 +265,7 @@ class MessagesHandlerMixIn(object):
         if msgid.lower() in self._checkers:
             for checker in self._checkers[msgid.lower()]:
                 for _msgid in checker.msgs:
-                    if _msgid in self._messages:
+                    if _msgid in self._alternative_names:
                         self.disable(_msgid, scope, line)
             return
         # msgid is report id?
@@ -306,13 +331,14 @@ class MessagesHandlerMixIn(object):
 
         Raises UnknownMessage if the message id is not defined.
         """
-        if msgid in self._messages_by_symbol:
-            return self._messages_by_symbol[msgid]
-        msgid = msgid.upper()
-        try:
-            return self._messages[msgid]
-        except KeyError:
-            raise UnknownMessage('No such message id %s' % msgid)
+        if msgid[1:].isdigit():
+            msgid = msgid.upper()
+        for source in (self._alternative_names, self._messages):
+            try:
+                return source[msgid]
+            except KeyError:
+                pass
+        raise UnknownMessage('No such message id %s' % msgid)
 
     def get_msg_display_string(self, msgid):
         """Generates a user-consumable representation of a message.
@@ -329,14 +355,19 @@ class MessagesHandlerMixIn(object):
         except (KeyError, TypeError):
             return MSG_STATE_SCOPE_CONFIG
 
-    def is_message_enabled(self, msgid, line=None):
+    def is_message_enabled(self, msg_descr, line=None):
         """return true if the message associated to the given message id is
         enabled
 
         msgid may be either a numeric or symbolic message id.
         """
-        if msgid in self._messages_by_symbol:
-            msgid = self._messages_by_symbol[msgid].msgid
+        try:
+            msgid = self.check_message_id(msg_descr).msgid
+        except UnknownMessage:
+            # The linter checks for messages that are not registered
+            # due to version mismatch, just treat them as message IDs
+            # for now.
+            msgid = msg_descr
         if line is None:
             return self._msgs_state.get(msgid, True)
         try:
@@ -396,9 +427,9 @@ class MessagesHandlerMixIn(object):
         self.stats[msg_cat] += 1
         self.stats['by_module'][self.current_name][msg_cat] += 1
         try:
-            self.stats['by_msg'][msgid] += 1
+            self.stats['by_msg'][msg_info.symbol] += 1
         except KeyError:
-            self.stats['by_msg'][msgid] = 1
+            self.stats['by_msg'][msg_info.symbol] = 1
         # expand message ?
         msg = msg_info.msg
         if args:
@@ -417,7 +448,7 @@ class MessagesHandlerMixIn(object):
         """display help messages for the given message identifiers"""
         for msgid in msgids:
             try:
-                print self.get_message_help(msgid, True)
+                print self.check_message_id(msgid).format_help(checkerref=True)
                 print
             except UnknownMessage, ex:
                 print ex
@@ -467,8 +498,10 @@ class MessagesHandlerMixIn(object):
                 title = ('%smessages' % prefix).capitalize()
                 print title
                 print '~' * len(title)
-                for msgid in sort_msgs(msgs.iterkeys()):
-                    print self.get_message_help(msgid, False)
+                for msgid, msg in sorted(msgs.iteritems(),
+                                         key=lambda (k, v): (_MSG_ORDER.index(k[0]), k)):
+                    msg = build_message_def(checker, msgid, msg)
+                    print msg.format_help(checkerref=False)
                 print
             if reports:
                 title = ('%sreports' % prefix).capitalize()
@@ -479,14 +512,16 @@ class MessagesHandlerMixIn(object):
                 print
             print
 
+    @property
+    def messages(self):
+        """The list of all active messages."""
+        return self._messages.itervalues()
+
     def list_messages(self):
         """output full messages list documentation in ReST format"""
-        msgids = []
-        for msgid in self._messages:
-            msgids.append(msgid)
-        msgids.sort()
-        for msgid in msgids:
-            print self.get_message_help(msgid, False)
+        msgs = sorted(self._messages.itervalues(), key=lambda msg: msg.msgid)
+        for msg in msgs:
+            print msg.format_help(checkerref=False)
         print
 
 
@@ -507,7 +542,7 @@ class ReportsHandlerMixIn(object):
         checker is the checker defining the report
         """
         reportid = reportid.upper()
-        self._reports.setdefault(checker, []).append( (reportid, r_title, r_cb) )
+        self._reports.setdefault(checker, []).append((reportid, r_title, r_cb))
 
     def enable_report(self, reportid):
         """disable the report of the given id"""
@@ -577,24 +612,24 @@ def expand_modules(files_or_modules, black_list):
             try:
                 filepath = file_from_modpath(modname.split('.'))
                 if filepath is None:
-                    errors.append( {'key' : 'F0003', 'mod': modname} )
+                    errors.append({'key' : 'F0003', 'mod': modname})
                     continue
             except (ImportError, SyntaxError), ex:
                 # FIXME p3k : the SyntaxError is a Python bug and should be
                 # removed as soon as possible http://bugs.python.org/issue10588
-                errors.append( {'key': 'F0001', 'mod': modname, 'ex': ex} )
+                errors.append({'key': 'F0001', 'mod': modname, 'ex': ex})
                 continue
         filepath = normpath(filepath)
-        result.append( {'path': filepath, 'name': modname,
-                        'basepath': filepath, 'basename': modname} )
+        result.append({'path': filepath, 'name': modname,
+                       'basepath': filepath, 'basename': modname})
         if not (modname.endswith('.__init__') or modname == '__init__') \
                 and '__init__.py' in filepath:
             for subfilepath in get_module_files(dirname(filepath), black_list):
                 if filepath == subfilepath:
                     continue
                 submodname = '.'.join(modpath_from_file(subfilepath))
-                result.append( {'path': subfilepath, 'name': submodname,
-                                'basepath': filepath, 'basename': modname} )
+                result.append({'path': subfilepath, 'name': submodname,
+                               'basepath': filepath, 'basename': modname})
     return result, errors
 
 
